@@ -1,5 +1,5 @@
 package POEx::IRC::Client::Lite;
-$POEx::IRC::Client::Lite::VERSION = '0.002005';
+$POEx::IRC::Client::Lite::VERSION = '0.003001';
 use strictures 2;
 
 use Carp 'confess';
@@ -73,6 +73,14 @@ has ipv6 => (
   default   => sub { 0 },
 );
 
+has ssl => (
+  lazy      => 1,
+  is        => 'ro',
+  isa       => Bool,
+  writer    => 'set_ssl',
+  default   => sub { 0 },
+);
+
 has pass => (
   lazy      => 1,
   is        => 'ro',
@@ -346,6 +354,7 @@ sub _connect {
   $self->backend->create_connector(
     remoteaddr => $self->server,
     remoteport => $self->port,
+    ssl        => $self->ssl,
     (
       $self->has_ipv6 ? (ipv6 => $self->ipv6) : ()
     ),
@@ -592,8 +601,7 @@ No state is maintained; POEx::IRC::Client::Lite provides a
 minimalist interface to IRC and serves as a base class for stateful clients.
 
 This is early development software pulled out of a much larger in-progress
-project.
-
+project. 
 B<< See L<POE::Component::IRC> for a more mature POE IRC client library. >>
 
 =head2 new
@@ -621,6 +629,12 @@ Boolean value indicating whether to prefer IPv6.
 
 Remote port to use (defaults to 6667).
 
+=item ssl
+
+Boolean value indicating whether to (attempt to) connect via SSL.
+
+Requires L<POE::Component::SSLify>.
+
 =item reconnect
 
 Reconnection attempt delay, in seconds.
